@@ -275,6 +275,7 @@ class AnnotateInsightResource:
         )
 
         resp.media = {
+            "status_code": annotation_result.status_code,
             "status": annotation_result.status,
             "description": annotation_result.description,
         }
@@ -641,6 +642,8 @@ class ImageLogoResource:
             join_image_model = True
 
         if min_confidence is not None:
+            # TODO(raphael): We should filter based on individual logo object confidence
+            # and not on image object with the maximum confidence
             where_clauses.append(ImagePrediction.max_confidence >= min_confidence)
             join_image_prediction = True
 
@@ -782,6 +785,10 @@ class ImageLogoAnnotateResource:
 
 class ImageLogoUpdateResource:
     def on_post(self, req: falcon.Request, resp: falcon.Response):
+        """Bulk update logo annotations: change type and value of logos that have specific
+        types and values.
+
+        Because this endpoint mass-update annotations, leave it out of API documentation."""
         source_value = req.get_param("source_value", required=True)
         source_type = req.get_param("source_type", required=True)
         target_value = req.get_param("target_value", required=True)
@@ -1150,12 +1157,16 @@ class UnansweredQuestionCollection:
         count: int = req.get_param_as_int("count", min_value=1, default=25)
         question_type: str = req.get_param("type")
         value_tag: str = req.get_param("value_tag")
+        country: Optional[str] = req.get_param("country")
+        server_domain: Optional[str] = req.get_param("server_domain")
 
         query_parameters = {
-            "keep_types": [question_type],
+            "keep_types": [question_type] if question_type else None,
             "group_by_value_tag": True,
             "value_tag": value_tag,
             "limit": count,
+            "country": country,
+            "server_domain": server_domain,
         }
 
         get_insights_ = functools.partial(get_insights, **query_parameters)
@@ -1206,7 +1217,7 @@ class ImagePredictionCollection:
             response["image_predictions"] = []
             response["status"] = "no_image_predictions"
         else:
-            response["images"] = images
+            response["image_predictions"] = images
             response["status"] = "found"
 
         resp.media = response
@@ -1296,12 +1307,12 @@ api.add_route("/api/v1/images/logos/update", ImageLogoUpdateResource())
 api.add_route("/api/v1/questions/{barcode}", ProductQuestionsResource())
 api.add_route("/api/v1/questions/random", RandomQuestionsResource())
 api.add_route("/api/v1/questions/popular", PopularQuestionsResource())
-api.add_route("/api/v1/questions/unanswered/", UnansweredQuestionCollection())
+api.add_route("/api/v1/questions/unanswered", UnansweredQuestionCollection())
 api.add_route("/api/v1/status", StatusResource())
 api.add_route("/api/v1/health", HealthResource())
 api.add_route("/api/v1/dump", DumpResource())
 api.add_route("/api/v1/users/statistics/{username}", UserStatisticsResource())
-api.add_route("/api/v1/predictions/", PredictionCollection())
+api.add_route("/api/v1/predictions", PredictionCollection())
 api.add_route("/api/v1/images/prediction/collection", ImagePredictionCollection())
 api.add_route("/api/v1/images", ImageCollection())
 api.add_route("/api/v1/annotation/collection", LogoAnnotationCollection())
