@@ -1,6 +1,7 @@
 import subprocess
 
 import click
+
 from robotoff import settings
 
 
@@ -10,7 +11,7 @@ def run(service: str):
             [
                 "gunicorn",
                 "--config",
-                str(settings.PROJECT_DIR / "gunicorn.conf"),
+                str(settings.PROJECT_DIR / "gunicorn.py"),
                 "robotoff.app.api:api",
             ]
         )
