@@ -28,6 +28,7 @@ logger = get_logger(__name__)
 
 @dataclass
 class AnnotationResult:
+    status_code: int
     status: str
     description: Optional[str] = None
 
@@ -35,37 +36,47 @@ class AnnotationResult:
 class AnnotationStatus(Enum):
     saved = 1
     updated = 2
-    vote_saved = 9
     error_missing_product = 3
     error_updated_product = 4
     error_already_annotated = 5
     error_unknown_insight = 6
     error_missing_data = 7
+    error_invalid_image = 8
+    vote_saved = 9
 
 
 SAVED_ANNOTATION_RESULT = AnnotationResult(
-    status=AnnotationStatus.saved.name, description="the annotation was saved"
+    status_code=AnnotationStatus.saved.value,
+    status=AnnotationStatus.saved.name,
+    description="the annotation was saved",
 )
 UPDATED_ANNOTATION_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.updated.value,
     status=AnnotationStatus.updated.name,
     description="the annotation was saved and sent to OFF",
 )
 MISSING_PRODUCT_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.error_missing_product.value,
     status=AnnotationStatus.error_missing_product.name,
     description="the product could not be found on OFF",
 )
 ALREADY_ANNOTATED_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.error_already_annotated.value,
     status=AnnotationStatus.error_already_annotated.name,
     description="the insight has already been annotated",
 )
 UNKNOWN_INSIGHT_RESULT = AnnotationResult(
-    status=AnnotationStatus.error_unknown_insight.name, description="unknown insight ID"
+    status_code=AnnotationStatus.error_unknown_insight.value,
+    status=AnnotationStatus.error_unknown_insight.name,
+    description="unknown insight ID",
 )
 DATA_REQUIRED_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.error_missing_data.value,
     status=AnnotationStatus.error_missing_data.name,
     description="annotation data is required as JSON in `data` field",
 )
 SAVED_ANNOTATION_VOTE_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.vote_saved.value,
     status=AnnotationStatus.vote_saved.name,
     description="the annotation vote was saved",
 )
@@ -107,12 +118,24 @@ class InsightAnnotator(metaclass=abc.ABCMeta):
         if automatic:
             insight.automatic_processing = True
 
-        insight.save()
-
         if annotation == 1 and update:
-            return self.process_annotation(insight, data=data, auth=auth)
+            # Save insight before processing the annotation
+            insight.save()
+            annotation_result = self.process_annotation(insight, data=data, auth=auth)
+        else:
+            annotation_result = SAVED_ANNOTATION_RESULT
 
-        return SAVED_ANNOTATION_RESULT
+        if annotation_result.status_code in (
+            AnnotationStatus.saved.value,
+            AnnotationStatus.updated.value,
+            AnnotationStatus.error_invalid_image.value,
+            AnnotationStatus.error_missing_product.value,
+            AnnotationStatus.error_updated_product.value,
+        ):
+            insight.annotated_result = annotation_result.status_code
+            insight.save()
+
+        return annotation_result
 
     @abc.abstractmethod
     def process_annotation(
@@ -196,7 +219,6 @@ class LabelAnnotator(InsightAnnotator):
             server_domain=insight.server_domain,
             auth=auth,
         )
-
         return UPDATED_ANNOTATION_RESULT
 
 
@@ -226,6 +248,7 @@ class IngredientSpellcheckAnnotator(InsightAnnotator):
                 barcode,
             )
             return AnnotationResult(
+                status_code=AnnotationStatus.error_updated_product.value,
                 status=AnnotationStatus.error_updated_product.name,
                 description="the ingredient list has been updated since spellcheck",
             )
@@ -265,7 +288,6 @@ class CategoryAnnotator(InsightAnnotator):
             server_domain=insight.server_domain,
             auth=auth,
         )
-
         return UPDATED_ANNOTATION_RESULT
 
 
@@ -293,7 +315,6 @@ class ProductWeightAnnotator(InsightAnnotator):
             server_domain=insight.server_domain,
             auth=auth,
         )
-
         return UPDATED_ANNOTATION_RESULT
 
 
@@ -343,6 +364,7 @@ class BrandAnnotator(InsightAnnotator):
             server_domain=insight.server_domain,
             auth=auth,
         )
+
         return UPDATED_ANNOTATION_RESULT
 
 
@@ -418,7 +440,8 @@ class NutritionImageAnnotator(InsightAnnotator):
 
         if not image_id:
             return AnnotationResult(
-                status="error_invalid_image",
+                status_code=AnnotationStatus.error_invalid_image.value,
+                status=AnnotationStatus.error_invalid_image.name,
                 description="the image is invalid",
             )
         image_key = "nutrition_{}".format(insight.value_tag)
@@ -442,7 +465,6 @@ class NutritionTableStructureAnnotator(InsightAnnotator):
     ) -> AnnotationResult:
         insight.data["annotation"] = data
         insight.save()
-
         return SAVED_ANNOTATION_RESULT
 
     def is_data_required(self):
