@@ -1,13 +1,18 @@
+import functools
 import re
 import unicodedata
 
 from spacy.lang.en import English
 from spacy.lang.fr import French
 
+from robotoff.utils import cache
+
+from .fold_to_ascii import fold
+
 CONSECUTIVE_SPACES_REGEX = re.compile(r" {2,}")
 
 
-def strip_accents_ascii(s):
+def strip_accents_ascii(s: str) -> str:
     """Transform accentuated unicode symbols into ascii or nothing
 
     Warning: this solution is only suited for languages that have a direct
@@ -27,6 +32,10 @@ def strip_accents_ascii(s):
     return nkfd_form.encode("ASCII", "ignore").decode("ASCII")
 
 
+def strip_accents_ascii_v2(s):
+    return fold(s)
+
+
 def strip_consecutive_spaces(text: str) -> str:
     """Convert a sequence of 2+ spaces into a single space."""
     return CONSECUTIVE_SPACES_REGEX.sub(" ", text)
@@ -39,3 +48,19 @@ def get_nlp(lang: str):
         return English()
     else:
         raise ValueError("unknown lang: {}".format(lang))
+
+
+def get_tag(text: str) -> str:
+    text = strip_accents_ascii_v2(text)
+    return (
+        text.lower()
+        .replace(" & ", "-")
+        .replace(" ", "-")
+        .replace("'", "-")
+        .replace(".", "-")
+    )
+
+
+FR_NLP_CACHE = cache.CachedStore(
+    functools.partial(get_nlp, lang="fr"), expiration_interval=None
+)
